@@ -12,21 +12,20 @@ import torch
 import torch.nn as nn
 
 
-__all__ = [
-    "PositionalEncoding"
-]
+__all__ = ["PositionalEncoding"]
 
 
 class PositionalEncoding(nn.Module):
     """
-    Attention is all you need. で提案された　Transformer モデルで用いられる Positional Encoding
+    ``Positional Encoding`` used in the ``Transformer`` model proposed in `Attention is all you need`.
 
     References:
         `Sequence-to-Sequence Modeling with nn.Transformer and TorchText \
         <https://pytorch.org/tutorials/beginner/transformer_tutorial.html#define-the-model>`_
 
     """
-    def __init__(self, d_model, seq_len, dropout=0.1):
+
+    def __init__(self, d_model: int, seq_len: int, dropout: float = 0.1) -> None:
         """
 
 
@@ -35,8 +34,8 @@ class PositionalEncoding(nn.Module):
             seq_len: length of input sequence.
             dropout: dropout rate.
         """
-        super().__init__()
-        self.dropout = nn.Dropout(p=dropout)
+        super(PositionalEncoding, self).__init__()
+        self.dropout: nn.Dropout = nn.Dropout(p=dropout)
 
         pe = torch.zeros(seq_len, d_model)
         position = torch.arange(0, seq_len, dtype=torch.float).unsqueeze(1)
@@ -46,18 +45,18 @@ class PositionalEncoding(nn.Module):
         pe = pe.unsqueeze(0).transpose(0, 1)
         self.register_buffer("pe", pe)
 
-    def forward(self, x):
+    def forward(self, x: torch.Tensor) -> torch.Tensor:
         """
+        Forward propagation
 
         Args:
-            x: (N, E, L)
-            N ... batch size
-            E ... features
-            L ... seq len
+            x: input data ``[N, F, L]``
 
         Returns:
 
+            (N, E, L)
+
         """
-        x = x.permute(2, 0, 1)
-        x = x + self.pe[:x.size(0), :]
-        return self.dropout(x)
+        x = x.permute(2, 0, 1)  # [L, N, E]
+        x = x + self.pe[: x.size(0), :]  # type: ignore
+        return self.dropout(x).permute(1, 2, 0)
